@@ -1,13 +1,7 @@
-# -*- coding: utf-8 -*-
 #
 #  This file is part of Sequana software
 #
-#  Copyright (c) 2016 - Sequana Development Team
-#
-#  File author(s):
-#      Thomas Cokelaer <thomas.cokelaer@pasteur.fr>
-#      Dimitri Desvillechabrol <dimitri.desvillechabrol@pasteur.fr>,
-#          <d.desvillechabrol@gmail.com>
+#  Copyright (c) 2016-2022 - Sequana Development Team
 #
 #  Distributed under the terms of the 3-clause BSD license.
 #  The full license is in the LICENSE file, distributed with this software.
@@ -467,7 +461,7 @@ def run_analysis(chrom, options, feature_dict):
                 command=" ".join(["sequana_coverage"] + sys.argv[1:]))
                 #directory=options.output_directory)
 
-if __name__ == "__main__":
+if __name__ == "__main__": #pragma: no cover
    import sys
    main()#sys.argv)
 
